## escape.manager

CMS da Escape para ser instalado com o Laravel 4. Instalação disponível via Composer.

### composer.json

Edite o seu arquivo `composer.json` adicionando o repositório do escape.manager.

```javascript
"require": {
    "escapework/manager": "0.2.*" 
}, 

"repositories": [
    {
        "type": "git",
        "url": "git@github.com:escapecriativacao/escape.manager.git"
    }
]
```

Depois, rode o comando `composer update`.

### Publicando o pacote e suas configurações

Edite o arquivo `app/config/app.php`, adicionando a seguinte linha no array de providers: 

```php
    'EscapeWork\Manager\ManagerServiceProvider'
```

Também adicione os aliases para o [EscapeWork\Msg](https://github.com/EscapeWork/Msg) e o [EscapeWork\LaravelHelpers](https://github.com/EscapeWork/LaravelHelpers);

```php
    'Eloquent'        => 'EscapeWork\LaravelHelpers\Eloquent',
    'Msg'             => 'EscapeWork\Msg\Msg', 
    'Check'           => 'EscapeWork\Manager\Check', 
```

Depois de baixar o pacote, execute os seguintes comandos: 

- `$ php artisan config:publish escapework/manager`
- `$ php artisan asset:publish escapework/manager`
- `$ php artisan migrate --package="escapework/manager"`

Agora, precisamos executar os seeds, e criar o primeiro usuário. Para isso, abra o arquivo `app/database/seeds/DatabaseSeeder.php`, e adicione a seguinte linha: 

```php
# from package escapework/manager
$this->call('EscapeWork\Manager\Seed\ManagerTableSeeder');
```

Depois, executa o comando de seed.

`$ php artisan db:seed`

Altere o model utilizado pela classe de autenticação, alterando a linha no arquivo `app/config/auth.php`

```php
    'model' => 'EscapeWork\Manager\Model\User',
```

Agora, a URL `seudominio.dev/manager` já está disponível para acesso.

***

### Templates

Para extender o layout master, utilize da seguinte forma: 

```php
@extends('manager::layouts.master')

@section('styles')
    <link href="/css" rel="stylesheet" type="text/css" />
@stop

@section('content')
    Contúdo da página
@stop

@section('scripts')
    <script src="/js" type="text/javascript"></script>
@stop
```

Para editar o menu, crie um template chamado `menu.blade.php` na raiz do seu projeto. Caso queira utilizar outro nome, altere a configuração `menu`, nas configurações do escape.manager.

```php
<li><a href="{{ route('manager.clientes.index') }}">Clientes</a></li>
<li><a href="{{ route('categorias.index') }}">Categorias</a></li>
```

***

### Permissões de acesso

Para testar as permissões de acesso, utilize o seguinte comando: 

```php
Check::can('categories', 'read'); // (page|action) true or false

@if (Check::can('users', 'create'))
    <a href="#" class="btn">Insert new user</a>
@endif
```

Para exibir ou não exibir no menu, pode-se testar como no exemplo abaixo, verificando se o usuário tem pelo menos 1 permissão de acesso a página.

```php
@if (Check::canAny('users')
    <a href="{{ route('usuarios.index') }}" class="btn">Usuários</a>
@endif
```

Você também pode testar a permissão de acesso diretamente no seu controller.

```php
use EscapeWork\Manager\Controller\ManagerController;

class UserController extends ManagerController
{

    public function __construct()
    {
        $this->beforeFilter(function()
        {
            Check::canOrFail('users', 'create');
        }, array('only' => array('create', 'store')));

        $this->beforeFilter(function()
        {
            Check::canOrFail('users', 'update');
        }, array('only' => array('edit', 'update')));
    }
}
```

### Templates

Você pode reescrever o template padrão da home. Para isso, basta alterar o array de configurações de templates que fica em `app/config/packages/escapework/manager/config.php`.

```php
    /**
     * Templates que podem ser sobreescritor
     */
    'templates' => array(
        'home' => 'manager::home', 
    ), 
```

#### Dependências e Componentes

O **escape.manager** utiliza os seguintes componentes: 

- [EscapeWork/Msg](https://github.com/EscapeWork/Msg)
- [EscapeWork/LaravelHelpers](https://github.com/EscapeWork/LaravelHelpers)
- [Twitter Bootstrap](http://twitter.github.io/bootstrap/)
- [jQuery](http://jquery.com/)
- [jQuery UI](http://jqueryui.com/)