<?php namespace EscapeWork\Manager\Controller;

use EscapeWork\Manager\Model\Page;
use App;
use Input;
use Redirect;
use Msg;
use View;

class PageController extends ManagerController
{

    public function __construct()
    {
        parent::__construct();
        
        $this->page       = App::make('PageRepository');
        $this->pageAction = App::make('PageActionRepository');
        $this->roleAction = App::make('RoleActionRepository');

        $this->enableDefaultFilters('usuarios');
    }

    /**
     * Listing the pages
     */
    public function index()
    {
        $view        = View::make('manager::pages.index');
        $view->pages = $this->page->get();

        return $view;
    }

    /**
     * Form for creating a page
     */
    public function create()
    {
        Msg::setInfo('Inserindo uma nova página');

        $view             = View::make('manager::pages.form');
        $view->page       = $this->page;
        $view->edit       = false;
        $view->pageAction = $this->pageAction;
        $view->actions    = $this->pageAction->getDefaultActions();

        return $view;
    }

    /**
     * Storing a new page
     */
    public function store()
    {
        $fields = Input::all();

        if (! $this->page->validate($fields)) {
            return Redirect::route('manager.pages.create')
                    ->withInput()
                    ->with('errors', Page::$messages);
        }

        $this->page->fill($fields);
        $this->page->save();

        # saving the actions 
        $this->pageAction->page_id = $this->page->id;
        $this->pageAction->saveAll(Input::get('actionTitle'), Input::get('actionType'));

        return Redirect::route('manager.pages.index')
                ->with('message', 'A página <strong>'.$this->page->title.'</strong> foi inserida com sucesso!');
    }

    /**
     * Form for editing a page
     */
    public function edit($id)
    {
        if (! $this->page = $this->page->find($id)) {
            return Redirect::route('manager.pages.index')
                    ->with('error', 'Regra não encontrada');
        }

        Msg::setInfo('Editando a regra <strong>'.$this->page->title.'</strong>');

        $view             = View::make('manager::pages.form');
        $view->page       = $this->page;
        $view->pageAction = $this->pageAction;
        $view->edit       = true;
        $view->actions    = $this->pageAction->getByPage($this->page->id);

        return $view;
    }

    /**
     * Updating the page
     */
    public function update($id)
    {
        if (! $this->page = $this->page->find($id)) {
            return Redirect::route('manager.pages.index')
                    ->with('error', 'Regra não encontrada');
        }

        $fields = Input::all();

        if (! $this->page->validate($fields)) {
            return Redirect::route('manager.pages.edit', $this->page->id)
                    ->withInput()
                    ->with('errors', Page::$messages);
        }

        $this->page->fill($fields);
        $this->page->save();

        $redirect = Redirect::route('manager.pages.index');

        if ($this->pageAction->hasChanged($this->pageAction->getByPage($this->page->id), Input::get('actionType'))) {
            $this->pageAction->page_id = $this->page->id;
            $this->roleAction->deleteByPage($this->page->id);
            $this->pageAction->deleteByPage($this->page->id);
            $this->pageAction->saveAll(Input::get('actionTitle'), Input::get('actionType'));

            $redirect->with('warning', 'Como as ações da página <strong>'.$this->page->title.'</strong> foram modificadas, é necessário liberar as permissões novamente para os perfis. <a href="'.route('manager.roles.index').'">Clique aqui</a> para ir para a página de perfis.');
        }

        return $redirect->with('message', 'A regra <strong>'.$this->page->title.'</strong> foi atualizada com sucesso!');
    }

    /**
     * Destroying the page
     */
    public function destroy($id)
    {
        if (! $this->page = $this->page->find($id)) {
            return Redirect::route('manager.pages.index')
                    ->with('error', 'Regra não encontrada');
        }

        $this->roleAction->deleteByPage($this->page->id);
        $this->pageAction->deleteByPage($this->page->id);
        $this->page->delete();

        return Redirect::route('manager.pages.index')
                ->with('message', 'A página <strong>'.$this->page->title.'</strong> foi excluída com sucesso!');
    }
}