<?php namespace EscapeWork\Manager;

use Illuminate\Support\ServiceProvider;
use Auth;

class ManagerServiceProvider extends ServiceProvider
{

    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;
    
    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->package('escapework/manager');

        require_once(__DIR__ . '/../../routes.php');
        $this->registerPermission();
    }

    /**
     * Registering the permission check class
     */
    protected function registerPermission()
    {
        $this->app['escapework.manager.permission'] = $this->app->share(function($app)
        {
            if (!$user = Auth::user()) {
                $user = new Model\User;
            }
            
            $permission = new Permission($user, new Model\RoleAction);
            $permission->fetchAllowedActions()
                       ->formatAllowedActionsArray();

            return $permission;
        });
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return array('escapework.manager.permission');
    }
}